pitcharraytools.make_empty_pitch_array_from_list_of_pitch_lists
===============================================================

.. autofunction:: abjad.tools.pitcharraytools.make_empty_pitch_array_from_list_of_pitch_lists.make_empty_pitch_array_from_list_of_pitch_lists
